summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrakeWPF/Properties/Resources.Designer.cs')
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.Designer.cs85
1 files changed, 83 insertions, 2 deletions
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
index 584540135..149010d2e 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
+++ b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
@@ -1926,7 +1926,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
/// Looks up a localized string similar to Meta Data.
/// </summary>
public static string MainView_MetaDataTab {
get {
@@ -2457,7 +2457,70 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Meta Data.
+ /// Looks up a localized string similar to Actors:.
+ /// </summary>
+ public static string MetadataView_Actors {
+ get {
+ return ResourceManager.GetString("MetadataView_Actors", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Comments:.
+ /// </summary>
+ public static string MetadataView_Comments {
+ get {
+ return ResourceManager.GetString("MetadataView_Comments", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Description:.
+ /// </summary>
+ public static string MetadataView_Description {
+ get {
+ return ResourceManager.GetString("MetadataView_Description", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Director:.
+ /// </summary>
+ public static string MetadataView_Director {
+ get {
+ return ResourceManager.GetString("MetadataView_Director", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Genre:.
+ /// </summary>
+ public static string MetadataView_Genre {
+ get {
+ return ResourceManager.GetString("MetadataView_Genre", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Plot:.
+ /// </summary>
+ public static string MetadataView_Plot {
+ get {
+ return ResourceManager.GetString("MetadataView_Plot", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Release Date:.
+ /// </summary>
+ public static string MetadataView_ReleaseDate {
+ get {
+ return ResourceManager.GetString("MetadataView_ReleaseDate", resourceCulture);
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized string similar to Metadata.
/// </summary>
public static string MetaDataView_Title {
get {
@@ -2466,6 +2529,15 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
+ /// Looks up a localized string similar to Title:.
+ /// </summary>
+ public static string MetadataView_TitleTag {
+ get {
+ return ResourceManager.GetString("MetadataView_TitleTag", resourceCulture);
+ }
+ }
+
+ /// <summary>
/// Looks up a localized string similar to Encoding: Pass {0} of {1}, {2:00.00}%
///FPS: {3:000.0}, Avg FPS: {4:000.0}
///Time Remaining: {5}, Elapsed: {6:d\:hh\:mm\:ss}.
@@ -2995,6 +3067,15 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
+ /// Looks up a localized string similar to System.
+ /// </summary>
+ public static string Options_SystemOptions {
+ get {
+ return ResourceManager.GetString("Options_SystemOptions", resourceCulture);
+ }
+ }
+
+ /// <summary>
/// Looks up a localized string similar to Change case to Title Case.
/// </summary>
public static string Options_TitleCase {
@@ -1926,7 +1926,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Meta Data.
+ /// Looks up a localized string similar to Metadata.
/// </summary>
public static string MainView_MetaDataTab {